@@ -31,7 +31,7 @@ class GitDiffTool(object):
         Raises a `GitDiffError` if `git diff` outputs anything
         to stderr.
         """
-        return self._execute(['git', 'diff', 'origin/master...HEAD'])
+        return self._execute(['git', 'diff', 'origin/master...HEAD', '--no-ext-diff'])
 
     def diff_unstaged(self):
         """
@@ -41,7 +41,7 @@ class GitDiffTool(object):
         Raises a `GitDiffError` if `git diff` outputs anything
         to stderr.
         """
-        return self._execute(['git', 'diff'])
+        return self._execute(['git', 'diff', '--no-ext-diff'])
 
     def diff_staged(self):
         """
@@ -51,7 +51,7 @@ class GitDiffTool(object):
         Raises a `GitDiffError` if `git diff` outputs anything
         to stderr.
         """
-        return self._execute(['git', 'diff', '--cached'])
+        return self._execute(['git', 'diff', '--cached', '--no-ext-diff'])
 
     def _execute(self, command):
         """
